Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2011-12-04 22:39:19 +0400
committerCampbell Barton <ideasman42@gmail.com>2011-12-04 22:39:19 +0400
commit22a1ad61f93a4b060500e5295c58b128f24a2daf (patch)
tree5693c7acd41e5d325cf3f6f1675cbceb232dd8a4 /source/blender/makesdna/DNA_mesh_types.h
parenta115c02605b2692710f5d9b64d87407b7ca5b374 (diff)
parent937c5494c4933c65635450e66aeacffed74939f2 (diff)
svn merge ^/trunk/blender -r42372:42416
Diffstat (limited to 'source/blender/makesdna/DNA_mesh_types.h')
-rw-r--r--source/blender/makesdna/DNA_mesh_types.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/source/blender/makesdna/DNA_mesh_types.h b/source/blender/makesdna/DNA_mesh_types.h
index 125c18fa7c4..443bdfe8dd6 100644
--- a/source/blender/makesdna/DNA_mesh_types.h
+++ b/source/blender/makesdna/DNA_mesh_types.h
@@ -31,6 +31,7 @@
* \ingroup DNA
*/
+#include "DNA_defs.h"
#include "DNA_listBase.h"
#include "DNA_ID.h"
#include "DNA_customdata_types.h"
@@ -62,7 +63,7 @@ typedef struct Mesh {
struct BoundBox *bb;
- struct Ipo *ipo; // XXX depreceated... old animation system
+ struct Ipo *ipo DNA_DEPRECATED; /* old animation system, deprecated for 2.5 */
struct Key *key;
struct Material **mat;
@@ -109,13 +110,13 @@ typedef struct Mesh {
short texflag, drawflag;
short smoothresh, flag;
- short subdiv, subdivr;
- char subsurftype; /* only kept for backwards compat, not used anymore */
+ short subdiv DNA_DEPRECATED, subdivr DNA_DEPRECATED;
+ char subsurftype DNA_DEPRECATED; /* only kept for backwards compat, not used anymore */
char editflag;
short totcol;
- struct Multires *mr; /* deprecated multiresolution modeling data, only keep for loading old files */
+ struct Multires *mr DNA_DEPRECATED; /* deprecated multiresolution modeling data, only keep for loading old files */
struct PartialVisibility *pv;
} Mesh;